==> CGSocialApp-1.1.10.tar.gz: CGSocialApp/function.admin_activities_tab.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: FrontEndUsers (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Site Preferences') ) exit;

//
// initialization
//

//
// get the data
//
$activities = cgsa_activity::load_all_as_array();
if( is_array($activities) && count($activities) )
  {
    for( $i = 0; $i < count($activities); $i++ )
      {
	$rec =& $activities[$i];
	$rec['depth'] = max(0,count(explode('.',$rec['hierarchy']))-1);
	$rec['edit_url'] = $this->CreateURL($id,'admin_addactivity',$returnid,
					    array('actid'=>$rec['id']));
	$rec['edit_link'] = $this->CreateImageLink($id,'admin_addactivity',$returnid,
						   $this->Lang('edit'),
						   'icons/system/edit.gif',
						   array('actid'=>$rec['id']));
	$rec['delete_link'] = $this->CreateImageLink($id,'admin_delactivity',$returnid,
						     $this->Lang('delete'),
						     'icons/system/delete.gif',
						     array('actid'=>$rec['id']));
      }
    $smarty->assign('activities',$activities);
  }

//
// give everything to smarty
//
$smarty->assign('addlink',
		$this->CreateImageLink($id,'admin_addactivity',$returnid,
				       $this->Lang('add_activity'),
				       'icons/system/newobject.gif',
				       array(),'','','FALSE'));
if( count($activities))
  {
    $smarty->assign('orderlink',
		    $this->CreateImageLink($id,'admin_orderactivity',$returnid,
					   $this->Lang('reorder_activity'),
					   'icons/system/reorder.gif',
					   array(),'','','FALSE'));
  }
echo $this->ProcessTemplate('admin_activities_tab.tpl');
#
# EOF
#
?>

==> CGSocialApp-1.3.1.tar.gz: CGSocialApp/function.admin_activities_tab.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: FrontEndUsers (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Site Preferences') ) exit;

//
// initialization
//

//
// get the data
//
$activities = cgsa_activity::load_all_as_tree();
$smarty->assign('activities',$activities);
// debug_display($activities); return;
// if( is_array($activities) && count($activities) ) {
//   for( $i = 0; $i < count($activities); $i++ ) {
//     $rec =& $activities[$i];
//     $rec['depth'] = max(0,count(explode('.',$rec['hierarchy']))-1);
//     $rec['edit_url'] = $this->CreateURL($id,'admin_addactivity',$returnid,
// 					array('actid'=>$rec['id']));
//     $rec['edit_link'] = $this->CreateImageLink($id,'admin_addactivity',$returnid,
// 					       $this->Lang('edit'),
// 					       'icons/system/edit.gif',
// 					       array('actid'=>$rec['id']));
//     $rec['delete_link'] = $this->CreateImageLink($id,'admin_delactivity',$returnid,
// 						 $this->Lang('delete'),
// 						 'icons/system/delete.gif',
// 						 array('actid'=>$rec['id']));
//   }
//   $smarty->assign('activities',$activities);
// }

//
// give everything to smarty
//
$smarty->assign('addlink',
		$this->CreateImageLink($id,'admin_addactivity',$returnid,
				       $this->Lang('add_activity'),
				       'icons/system/newobject.gif',
				       array(),'','','FALSE'));
if( count($activities)) {
  $smarty->assign('orderlink',
		  $this->CreateImageLink($id,'admin_orderactivity',$returnid,
					 $this->Lang('reorder_activity'),
					 'icons/system/reorder.gif',
					 array(),'','','FALSE'));
}

echo $this->ProcessTemplate('admin_activities_tab.tpl');
#
# EOF
#
?>
